summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jabberaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jabberaccount.h')
-rw-r--r--kopete/protocols/jabber/jabberaccount.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/jabber/jabberaccount.h b/kopete/protocols/jabber/jabberaccount.h
index 3d174639..04b79770 100644
--- a/kopete/protocols/jabber/jabberaccount.h
+++ b/kopete/protocols/jabber/jabberaccount.h
@@ -168,12 +168,12 @@ protected:
* method should have the "dirty" flag set.
*
* This method should simply be used to intantiate the new contact, everything else
- * (updating the GUI, tqparenting to meta contact, etc.) is being taken care of.
+ * (updating the GUI, parenting to meta contact, etc.) is being taken care of.
*
* @param contactId The unique ID for this protocol
* @param tqparentContact The metacontact to add this contact to
*/
- virtual bool createContact (const TQString & contactID, Kopete::MetaContact * tqparentContact);
+ virtual bool createContact (const TQString & contactID, Kopete::MetaContact * parentContact);
@@ -168,12 +168,12 @@ protected:
*
* @param contactId The unique ID for this protocol
- * @param tqparentContact The metacontact to add this contact to
+ * @param parentContact The metacontact to add this contact to
*/